﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace PictureEditor
{
    public partial class Form1 : Form
    {
        /** member variable of image editor object **/
        private ImageEditor m_imageEditor = new ImageEditor();
 
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //nothing to do at the moment
        }

        /*
         * Validate resize image fields , make sure not blank
         * and input is valid
         * @param source is source file
         * @param destination is destination file
         * @param width is width 
         * @param height is height
         */
        private bool validateResize(string source, string destination,
                                    string width, string height)
        {
            bool result = false;

            //if one of the required fields is blank then return false
            if (
                (source.Trim().Length == 0) || (destination.Trim().Length == 0)
                || (width.Trim().Length == 0) || (height.Trim().Length == 0)
                )
            {
                return result;
            }

            //if width and height is not integer, return false
            try
            {
                int w = Convert.ToInt32(width);
                int h = Convert.ToInt32(height);

                if((w > 0) ||(h > 0)) result = true;
            }
            catch (Exception) { }

            return result;
        }

        /*
         * Browse file / folder
         * @param folder if we want to to browse folder/ not file
         */
        private string browse(bool folder)
        {
            string path = string.Empty;
            if (folder)
            {
                FolderBrowserDialog fbd = new FolderBrowserDialog();
                if (fbd.ShowDialog() == DialogResult.OK) path = fbd.SelectedPath;
            }
            else
            {
                OpenFileDialog ofd = new OpenFileDialog();
                if (ofd.ShowDialog() == DialogResult.OK) path = ofd.FileName;
            }
            return path;
        }

        /** event handler when user click resize folder **/
        private void cmd_resize_folder_Click(object sender, EventArgs e)
        {
            if (validateResize(txt_source_folder_resize.Text,
                              txt_destination_folder_resize.Text,
                              txt_width_folder.Text,
                              txt_height_folder.Text))
            {
                int w = Convert.ToInt32(txt_width_folder.Text);
                int h = Convert.ToInt32(txt_height_folder.Text);

                Size s = new Size(w, h);
                bool result = m_imageEditor.resizeFolder(
                                           txt_source_folder_resize.Text,
                                           txt_destination_folder_resize.Text,
                                           s);

                if (result)
                {
                    MessageBox.Show("Successfully resize folder");
                }
            }
            else
            {
                MessageBox.Show("Input is not valid, please try again");
            }
        }

        /** event handler when user click resize image **/
        private void cmd_resize_image_Click(object sender, EventArgs e)
        {
            if (validateResize(txt_source_resize_image.Text,
                            txt_destination_resize_image.Text,
                            txt_witdh_image.Text,
                            txt_height_image.Text))
            {
                int w = Convert.ToInt32(txt_witdh_image.Text);
                int h = Convert.ToInt32(txt_height_image.Text);

                Size s = new Size(w, h);
                bool result = m_imageEditor.resizeImage(
                                           txt_source_resize_image.Text,
                                           txt_destination_resize_image.Text,
                                           s);

                if (result)
                {
                    MessageBox.Show("Successfully resize image");
                }
            }
            else
            {
                MessageBox.Show("Input is not valid, please try again");
            }
        }

        /** event handler when user click browse source resize folder **/
        private void cmd_browse_source_resize_folder_Click(object sender, EventArgs e)
        {
            txt_source_folder_resize.Text = browse(true);
        }

        /** event handler when user click browse destination resize folder **/
        private void cmd_browse_destination_resize_folder_Click(object sender, EventArgs e)
        {
            txt_destination_folder_resize.Text = browse(true);
        }

        /** event handler when user click browse source resize image **/
        private void cmd_browse_source_resize_image_Click(object sender, EventArgs e)
        {
            txt_source_resize_image.Text = browse(false);
        }  

        /** event handler when user click browse destination resize image **/
        private void cmd_browse_destination_resize_image_Click(object sender, EventArgs e)
        {
            txt_destination_resize_image.Text = browse(false);
        }

        /** event handler when we click browse in flip tab **/
        private void cmd_browse_flip_image_Click(object sender, EventArgs e)
        {
            txt_source_flip_image.Text = browse(false);

            //load image
            try
            {
                pb_flip_image.Load(txt_source_flip_image.Text);
            }
            catch (Exception)
            {
                MessageBox.Show(" Invalid input format ");
            }
        }

        /** event handler when user click browse rotate **/
        private void cmd_browse_rotate_Click(object sender, EventArgs e)
        {
            txt_source_image_rotate.Text = browse(false);
            
            //load image
            try
            {
                pbRotate.Load(txt_source_image_rotate.Text);
            }
            catch (Exception)
            {
                MessageBox.Show(" Invalid input format ");
            }
        }

        /** event handler when user click rotate button **/
        private void cmd_rotate_image_Click(object sender, EventArgs e)
        {
            float angle = 0;

            //validate the fields, make sure all fill
            if (
                (cmb_angle.Text.Trim().Length == 0) ||
                (txt_source_image_rotate.Text.Trim().Length == 0)
                )
            {
                MessageBox.Show("Input is not valid, Please try again");
                return;
            }

            //validate the angle, make sure it is digit
            try
            {
                angle = Convert.ToSingle(cmb_angle.Text);
            }
            catch (Exception)
            {
                MessageBox.Show("Input is not valid, Please try again");
                return;
            }
            string new_file = string.Empty;
            bool result = m_imageEditor.rotateImage(txt_source_image_rotate.Text,
                                                    angle, ref new_file);

            if (result)
            {
                pbRotate.Load(new_file);
                MessageBox.Show(" Rotate Image success");
            }            
        }

        /** event handler when we click flip button **/
        private void cmd_flip_image_Click(object sender, EventArgs e)
        {

            //validate the fields, make sure all fill
            if (
                (cmb_flip.Text.Trim().Length == 0) ||
                (txt_source_flip_image.Text.Trim().Length == 0)
                )
            {
                MessageBox.Show("Input is not valid, Please try again");
                return;
            }

            string new_file = string.Empty;
            bool result = m_imageEditor.flipImage(txt_source_flip_image.Text,
                                                    cmb_flip.Text, ref new_file);

            if (result)
            {
                pb_flip_image.Load(new_file);
                MessageBox.Show(" Flip Image success");
            }            
        }

        /** event handler when we click save button **/
        private void cmd_save_rotate_image_Click(object sender, EventArgs e)
        {            
            string temp = pbRotate.ImageLocation;
            File.Copy(temp, txt_source_image_rotate.Text, true);

            pbRotate.Load(txt_source_image_rotate.Text);
            File.Delete(temp);

            MessageBox.Show("Successfully rotate image");
        }

        /** event handler when we click save flip button **/
        private void cmd_save_flip_image_Click(object sender, EventArgs e)
        {
            string temp = pb_flip_image.ImageLocation;

            //copy temp to destination file
            File.Copy(temp, txt_source_flip_image.Text,true);

            pb_flip_image.Load(txt_source_flip_image.Text);

            //delete temporary file
            File.Delete(temp);

            MessageBox.Show("Successfully flip the image ");
        }        
    }
}
